==> ExternalSiteCatalog-1.1.tgz: ExternalSiteCatalog/permission.py <==
# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""
ExternalSite specific permissions.
"""
__version__ = "$Revision: 1.3 $"
# $Source: /cvsroot/ingeniweb/ExternalSiteCatalog/permission.py,v $
# $Id: permission.py,v 1.3 2006/04/28 14:49:00 roeder Exp $
__docformat__ = 'restructuredtext'

from Products.CMFCore.CMFCorePermissions import setDefaultRoles
from Products.CMFCore import permissions as CCP

ConfigureExternalSites = 'ExternalSiteCatalog: Configure External Sites'

# Set up default roles for permissions
setDefaultRoles(ConfigureExternalSites, ('Manager',))

permissions = {'ExternalSiteCatalogTask':CCP.ManagePortal,
               'ExternalSiteCatalogTaskProperties':ConfigureExternalSites,
               'ExternalSiteCatalog':ConfigureExternalSites}

==> ExternalSiteCatalog-1.2.0.tgz: ExternalSiteCatalog/permission.py <==
# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""
ExternalSite specific permissions.
"""
__version__ = "$Revision: 1.4 $"
# $Source: /cvsroot/ingeniweb/ExternalSiteCatalog/permission.py,v $
# $Id: permission.py,v 1.4 2006/12/04 15:41:35 roeder Exp $
__docformat__ = 'restructuredtext'

try:
    from Products.CMFCore import permissions as CMFCorePermissions
except ImportError:
    from Products.CMFCore import CMFCorePermissions
try:
    from Products.CMFCore.permissions import setDefaultRoles
except ImportError:
    from Products.CMFCore.CMFCorePermissions import setDefaultRoles
    
ConfigureExternalSites = 'ExternalSiteCatalog: Configure External Sites'

# Set up default roles for permissions
setDefaultRoles(ConfigureExternalSites, ('Manager',))

permissions = {'ExternalSiteCatalogTask':CMFCorePermissions.ManagePortal,
               'ExternalSiteCatalogTaskProperties':ConfigureExternalSites,
               'ExternalSiteCatalog':ConfigureExternalSites}
